@@ -15,10 +15,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
+
 #include <string.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
@@ -27,14 +28,10 @@
 #include "gedit-file-bookmarks-store.h"
 #include "gedit-file-browser-utils.h"
 
-#define GEDIT_FILE_BOOKMARKS_STORE_GET_PRIVATE(object)( \
-		G_TYPE_INSTANCE_GET_PRIVATE((object), GEDIT_TYPE_FILE_BOOKMARKS_STORE, \
-		GeditFileBookmarksStorePrivate))
-
 struct _GeditFileBookmarksStorePrivate
 {
 	GVolumeMonitor *volume_monitor;
-	GFileMonitor *bookmarks_monitor;
+	GFileMonitor   *bookmarks_monitor;
 };
 
 static void remove_node               (GtkTreeModel            *model,
@@ -55,7 +52,11 @@ static gboolean find_with_flags       (GtkTreeModel            *model,
                                        guint                    flags,
                                        guint                    notflags);
 
-G_DEFINE_DYNAMIC_TYPE (GeditFileBookmarksStore, gedit_file_bookmarks_store, GTK_TYPE_TREE_STORE)
+G_DEFINE_DYNAMIC_TYPE_EXTENDED (GeditFileBookmarksStore,
+				gedit_file_bookmarks_store,
+				GTK_TYPE_TREE_STORE,
+				0,
+				G_ADD_PRIVATE_DYNAMIC (GeditFileBookmarksStore))
 
 static void
 gedit_file_bookmarks_store_dispose (GObject *object)
@@ -72,30 +73,17 @@ gedit_file_bookmarks_store_dispose (GObject *object)
 		obj->priv->volume_monitor = NULL;
 	}
 
-	if (obj->priv->bookmarks_monitor != NULL)
-	{
-		g_object_unref (obj->priv->bookmarks_monitor);
-		obj->priv->bookmarks_monitor = NULL;
-	}
+	g_clear_object (&obj->priv->bookmarks_monitor);
 
 	G_OBJECT_CLASS (gedit_file_bookmarks_store_parent_class)->dispose (object);
 }
 
-static void
-gedit_file_bookmarks_store_finalize (GObject *object)
-{
-	G_OBJECT_CLASS (gedit_file_bookmarks_store_parent_class)->finalize (object);
-}
-
 static void
 gedit_file_bookmarks_store_class_init (GeditFileBookmarksStoreClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
 	object_class->dispose = gedit_file_bookmarks_store_dispose;
-	object_class->finalize = gedit_file_bookmarks_store_finalize;
-
-	g_type_class_add_private (object_class, sizeof (GeditFileBookmarksStorePrivate));
 }
 
 static void
@@ -106,13 +94,14 @@ gedit_file_bookmarks_store_class_finalize (GeditFileBookmarksStoreClass *klass)
 static void
 gedit_file_bookmarks_store_init (GeditFileBookmarksStore *obj)
 {
-	obj->priv = GEDIT_FILE_BOOKMARKS_STORE_GET_PRIVATE (obj);
+	obj->priv = gedit_file_bookmarks_store_get_instance_private (obj);
 }
 
 /* Private */
 static void
 add_node (GeditFileBookmarksStore *model,
 	  GdkPixbuf               *pixbuf,
+	  const gchar             *icon_name,
 	  const gchar             *name,
 	  GObject                 *obj,
 	  guint                    flags,
@@ -124,6 +113,7 @@ add_node (GeditFileBookmarksStore *model,
 
 	gtk_tree_store_set (GTK_TREE_STORE (model), &newiter,
 			    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_ICON, pixbuf,
+			    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_ICON_NAME, icon_name,
 			    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_NAME, name,
 			    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_OBJECT, obj,
 			    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_FLAGS, flags,
@@ -140,29 +130,26 @@ add_file (GeditFileBookmarksStore *model,
 	  guint                    flags,
 	  GtkTreeIter             *iter)
 {
-	GdkPixbuf *pixbuf = NULL;
-	gboolean native;
+	gboolean native = g_file_is_native (file);
+	gchar *icon_name = NULL;
 	gchar *newname;
 
-	native = g_file_is_native (file);
-
 	if (native && !g_file_query_exists (file, NULL))
 		return FALSE;
 
 	if (flags & GEDIT_FILE_BOOKMARKS_STORE_IS_HOME)
-		pixbuf = gedit_file_browser_utils_pixbuf_from_theme ("user-home", GTK_ICON_SIZE_MENU);
+		icon_name = g_strdup ("user-home-symbolic");
 	else if (flags & GEDIT_FILE_BOOKMARKS_STORE_IS_DESKTOP)
-		pixbuf = gedit_file_browser_utils_pixbuf_from_theme ("user-desktop", GTK_ICON_SIZE_MENU);
+		icon_name = g_strdup ("user-desktop-symbolic");
 	else if (flags & GEDIT_FILE_BOOKMARKS_STORE_IS_ROOT)
-		pixbuf = gedit_file_browser_utils_pixbuf_from_theme ("drive-harddisk", GTK_ICON_SIZE_MENU);
-
-	if (pixbuf == NULL)
+		icon_name = g_strdup ("drive-harddisk-symbolic");
+	else
 	{
 		/* getting the icon is a sync get_info call, so we just do it for local files */
 		if (native)
-			pixbuf = gedit_file_browser_utils_pixbuf_from_file (file, GTK_ICON_SIZE_MENU);
+			icon_name = gedit_file_browser_utils_symbolic_icon_name_from_file (file);
 		else
-			pixbuf = gedit_file_browser_utils_pixbuf_from_theme ("folder", GTK_ICON_SIZE_MENU);
+			icon_name = g_strdup ("folder-symbolic");
 	}
 
 	if (name == NULL)
@@ -170,11 +157,9 @@ add_file (GeditFileBookmarksStore *model,
 	else
 		newname = g_strdup (name);
 
-	add_node (model, pixbuf, newname, G_OBJECT (file), flags, iter);
-
-	if (pixbuf)
-		g_object_unref (pixbuf);
+	add_node (model, NULL, icon_name, newname, G_OBJECT (file), flags, iter);
 
+	g_free (icon_name);
 	g_free (newname);
 
 	return TRUE;
@@ -186,17 +171,14 @@ check_mount_separator (GeditFileBookmarksStore *model,
 		       gboolean                 added)
 {
 	GtkTreeIter iter;
-	gboolean found;
-
-	found =
-	    find_with_flags (GTK_TREE_MODEL (model), &iter, NULL,
-			     flags | GEDIT_FILE_BOOKMARKS_STORE_IS_SEPARATOR,
-			     0);
+	gboolean found = find_with_flags (GTK_TREE_MODEL (model), &iter, NULL,
+					  flags | GEDIT_FILE_BOOKMARKS_STORE_IS_SEPARATOR,
+					  0);
 
 	if (added && !found)
 	{
 		/* Add the separator */
-		add_node (model, NULL, NULL, NULL,
+		add_node (model, NULL, NULL, NULL, NULL,
 			  flags | GEDIT_FILE_BOOKMARKS_STORE_IS_SEPARATOR,
 			  NULL);
 	}
@@ -209,24 +191,30 @@ check_mount_separator (GeditFileBookmarksStore *model,
 static void
 init_special_directories (GeditFileBookmarksStore *model)
 {
-	gchar const *path;
+	gchar const *path = g_get_home_dir ();
 	GFile *file;
 
-	path = g_get_home_dir ();
 	if (path != NULL)
 	{
 		file = g_file_new_for_path (path);
-		add_file (model, file, NULL, GEDIT_FILE_BOOKMARKS_STORE_IS_HOME |
-			 GEDIT_FILE_BOOKMARKS_STORE_IS_SPECIAL_DIR, NULL);
+		add_file (model,
+			  file,
+			  _("Home"),
+			  GEDIT_FILE_BOOKMARKS_STORE_IS_HOME | GEDIT_FILE_BOOKMARKS_STORE_IS_SPECIAL_DIR,
+			  NULL);
 		g_object_unref (file);
 	}
 
+#if defined(G_OS_WIN32) || OS_MACOS
 	path = g_get_user_special_dir (G_USER_DIRECTORY_DESKTOP);
 	if (path != NULL)
 	{
 		file = g_file_new_for_path (path);
-		add_file (model, file, NULL, GEDIT_FILE_BOOKMARKS_STORE_IS_DESKTOP |
-			  GEDIT_FILE_BOOKMARKS_STORE_IS_SPECIAL_DIR, NULL);
+		add_file (model,
+			  file,
+			  NULL,
+			  GEDIT_FILE_BOOKMARKS_STORE_IS_DESKTOP | GEDIT_FILE_BOOKMARKS_STORE_IS_SPECIAL_DIR,
+			  NULL);
 		g_object_unref (file);
 	}
 
@@ -234,10 +222,14 @@ init_special_directories (GeditFileBookmarksStore *model)
 	if (path != NULL)
 	{
 		file = g_file_new_for_path (path);
-		add_file (model, file, NULL, GEDIT_FILE_BOOKMARKS_STORE_IS_DOCUMENTS |
-			  GEDIT_FILE_BOOKMARKS_STORE_IS_SPECIAL_DIR, NULL);
+		add_file (model,
+			  file,
+			  NULL,
+			  GEDIT_FILE_BOOKMARKS_STORE_IS_DOCUMENTS | GEDIT_FILE_BOOKMARKS_STORE_IS_SPECIAL_DIR,
+			  NULL);
 		g_object_unref (file);
 	}
+#endif
 
 	file = g_file_new_for_uri ("file:///");
 	add_file (model, file, _("File System"), GEDIT_FILE_BOOKMARKS_STORE_IS_ROOT, NULL);
@@ -247,64 +239,61 @@ init_special_directories (GeditFileBookmarksStore *model)
 }
 
 static void
-get_fs_properties (gpointer    fs,
-		   gchar     **name,
-		   GdkPixbuf **pixbuf,
-		   guint      *flags)
+get_fs_properties (gpointer   fs,
+		   gchar    **name,
+		   gchar    **icon_name,
+		   guint     *flags)
 {
 	GIcon *icon = NULL;
 
 	*flags = GEDIT_FILE_BOOKMARKS_STORE_IS_FS;
 	*name = NULL;
-	*pixbuf = NULL;
+	*icon_name = NULL;
 
 	if (G_IS_DRIVE (fs))
 	{
-		icon = g_drive_get_icon (G_DRIVE (fs));
+		icon = g_drive_get_symbolic_icon (G_DRIVE (fs));
 		*name = g_drive_get_name (G_DRIVE (fs));
+		*icon_name = gedit_file_browser_utils_name_from_themed_icon (icon);
 
 		*flags |= GEDIT_FILE_BOOKMARKS_STORE_IS_DRIVE;
 	}
 	else if (G_IS_VOLUME (fs))
 	{
-		icon = g_volume_get_icon (G_VOLUME (fs));
+		icon = g_volume_get_symbolic_icon (G_VOLUME (fs));
 		*name = g_volume_get_name (G_VOLUME (fs));
+		*icon_name = gedit_file_browser_utils_name_from_themed_icon (icon);
 
 		*flags |= GEDIT_FILE_BOOKMARKS_STORE_IS_VOLUME;
 	}
 	else if (G_IS_MOUNT (fs))
 	{
-		icon = g_mount_get_icon (G_MOUNT (fs));
+		icon = g_mount_get_symbolic_icon (G_MOUNT (fs));
 		*name = g_mount_get_name (G_MOUNT (fs));
+		*icon_name = gedit_file_browser_utils_name_from_themed_icon (icon);
 
 		*flags |= GEDIT_FILE_BOOKMARKS_STORE_IS_MOUNT;
 	}
 
 	if (icon)
-	{
-		*pixbuf = gedit_file_browser_utils_pixbuf_from_icon (icon, GTK_ICON_SIZE_MENU);
 		g_object_unref (icon);
-	}
 }
 
-
 static void
 add_fs (GeditFileBookmarksStore *model,
 	gpointer                 fs,
 	guint                    flags,
 	GtkTreeIter             *iter)
 {
-	gchar *name;
-	GdkPixbuf *pixbuf;
+	gchar *icon_name = NULL;
+	gchar *name = NULL;
 	guint fsflags;
 
-	get_fs_properties (fs, &name, &pixbuf, &fsflags);
-	add_node (model, pixbuf, name, fs, flags | fsflags, iter);
-
-	if (pixbuf)
-		g_object_unref (pixbuf);
+	get_fs_properties (fs, &name, &icon_name, &fsflags);
+	add_node (model, NULL, icon_name, name, fs, flags | fsflags, iter);
 
 	g_free (name);
+	g_free (icon_name);
 	check_mount_separator (model, GEDIT_FILE_BOOKMARKS_STORE_IS_FS, TRUE);
 }
 
@@ -312,9 +301,8 @@ static void
 process_volume_cb (GVolume                 *volume,
 		   GeditFileBookmarksStore *model)
 {
-	GMount *mount;
+	GMount *mount = g_volume_get_mount (volume);
 	guint flags = GEDIT_FILE_BOOKMARKS_STORE_NONE;
-	mount = g_volume_get_mount (volume);
 
 	/* CHECK: should we use the LOCAL/REMOTE thing still? */
 	if (mount)
@@ -351,9 +339,7 @@ static void
 process_drive_cb (GDrive                  *drive,
 	          GeditFileBookmarksStore *model)
 {
-	GList *volumes;
-
-	volumes = g_drive_get_volumes (drive);
+	GList *volumes = g_drive_get_volumes (drive);
 
 	if (volumes)
 	{
@@ -370,9 +356,7 @@ process_drive_cb (GDrive                  *drive,
 static void
 init_drives (GeditFileBookmarksStore *model)
 {
-	GList *drives;
-
-	drives = g_volume_monitor_get_connected_drives (model->priv->volume_monitor);
+	GList *drives = g_volume_monitor_get_connected_drives (model->priv->volume_monitor);
 
 	g_list_foreach (drives, (GFunc)process_drive_cb, model);
 	g_list_free_full (drives, g_object_unref);
@@ -382,9 +366,7 @@ static void
 process_volume_nodrive_cb (GVolume                 *volume,
 			   GeditFileBookmarksStore *model)
 {
-	GDrive *drive;
-
-	drive = g_volume_get_drive (volume);
+	GDrive *drive = g_volume_get_drive (volume);
 
 	if (drive)
 	{
@@ -398,9 +380,7 @@ process_volume_nodrive_cb (GVolume                 *volume,
 static void
 init_volumes (GeditFileBookmarksStore *model)
 {
-	GList *volumes;
-
-	volumes = g_volume_monitor_get_volumes (model->priv->volume_monitor);
+	GList *volumes = g_volume_monitor_get_volumes (model->priv->volume_monitor);
 
 	g_list_foreach (volumes, (GFunc)process_volume_nodrive_cb, model);
 	g_list_free_full (volumes, g_object_unref);
@@ -410,9 +390,7 @@ static void
 process_mount_novolume_cb (GMount                  *mount,
 			   GeditFileBookmarksStore *model)
 {
-	GVolume *volume;
-
-	volume = g_mount_get_volume (mount);
+	GVolume *volume = g_mount_get_volume (mount);
 
 	if (volume)
 	{
@@ -428,9 +406,7 @@ process_mount_novolume_cb (GMount                  *mount,
 static void
 init_mounts (GeditFileBookmarksStore *model)
 {
-	GList *mounts;
-
-	mounts = g_volume_monitor_get_mounts (model->priv->volume_monitor);
+	GList *mounts = g_volume_monitor_get_mounts (model->priv->volume_monitor);
 
 	g_list_foreach (mounts, (GFunc)process_mount_novolume_cb, model);
 	g_list_free_full (mounts, g_object_unref);
@@ -475,12 +451,10 @@ add_bookmark (GeditFileBookmarksStore *model,
 	      gchar const             *name,
 	      gchar const             *uri)
 {
-	GFile *file;
-	gboolean ret;
+	GFile *file = g_file_new_for_uri (uri);
 	guint flags = GEDIT_FILE_BOOKMARKS_STORE_IS_BOOKMARK;
 	GtkTreeIter iter;
-
-	file = g_file_new_for_uri (uri);
+	gboolean ret;
 
 	if (g_file_is_native (file))
 		flags |= GEDIT_FILE_BOOKMARKS_STORE_IS_LOCAL_BOOKMARK;
@@ -490,92 +464,115 @@ add_bookmark (GeditFileBookmarksStore *model,
 	ret = add_file (model, file, name, flags, &iter);
 
 	g_object_unref (file);
-
 	return ret;
 }
 
+static gchar *
+get_bookmarks_file (void)
+{
+	return g_build_filename (g_get_user_config_dir (), "gtk-3.0", "bookmarks", NULL);
+}
+
+static gchar *
+get_legacy_bookmarks_file (void)
+{
+	return g_build_filename (g_get_home_dir (), ".gtk-bookmarks", NULL);
+}
+
+static gboolean
+parse_bookmarks_file (GeditFileBookmarksStore *model,
+		      const gchar             *bookmarks,
+		      gboolean                *added)
+{
+	GError *error = NULL;
+	gchar *contents;
+	gchar **lines;
+	gchar **line;
+
+	if (!g_file_get_contents (bookmarks, &contents, NULL, &error))
+	{
+		/* The bookmarks file doesn't exist (which is perfectly fine) */
+		g_error_free (error);
+
+		return FALSE;
+	}
+
+	lines = g_strsplit (contents, "\n", 0);
+
+	for (line = lines; *line; ++line)
+	{
+		if (**line)
+		{
+			GFile *location;
+
+			gchar *pos;
+			gchar *name;
+
+			/* CHECK: is this really utf8? */
+			pos = g_utf8_strchr (*line, -1, ' ');
+
+			if (pos != NULL)
+			{
+				*pos = '\0';
+				name = pos + 1;
+			}
+			else
+			{
+				name = NULL;
+			}
+
+			/* the bookmarks file should contain valid
+			 * URIs, but paranoia is good */
+			location = g_file_new_for_uri (*line);
+			if (gedit_utils_is_valid_location (location))
+			{
+				*added |= add_bookmark (model, name, *line);
+			}
+			g_object_unref (location);
+		}
+	}
+
+	g_strfreev (lines);
+	g_free (contents);
+
+	/* Add a watch */
+	if (model->priv->bookmarks_monitor == NULL)
+	{
+		GFile *file = g_file_new_for_path (bookmarks);
+
+		model->priv->bookmarks_monitor = g_file_monitor_file (file, G_FILE_MONITOR_NONE, NULL, NULL);
+		g_object_unref (file);
+
+		g_signal_connect (model->priv->bookmarks_monitor,
+				  "changed",
+				  G_CALLBACK (on_bookmarks_file_changed),
+				  model);
+	}
+
+	return TRUE;
+}
+
 static void
 init_bookmarks (GeditFileBookmarksStore *model)
 {
-	gchar *bookmarks;
-	GError *error = NULL;
-	gchar *contents;
-	gchar **lines;
-	gchar **line;
+	gchar *bookmarks = get_bookmarks_file ();
 	gboolean added = FALSE;
 
-	/* Read the bookmarks file */
-	bookmarks = g_build_filename (g_get_home_dir (),
-				      ".gtk-bookmarks",
-				      NULL);
-
-	if (g_file_get_contents (bookmarks, &contents, NULL, &error))
+	if (!parse_bookmarks_file (model, bookmarks, &added))
 	{
-		lines = g_strsplit (contents, "\n", 0);
+		g_free (bookmarks);
 
-		for (line = lines; *line; ++line)
-		{
-			if (**line)
-			{
-				GFile *location;
-
-				gchar *pos;
-				gchar *name;
-
-				/* CHECK: is this really utf8? */
-				pos = g_utf8_strchr (*line, -1, ' ');
-
-				if (pos != NULL)
-				{
-					*pos = '\0';
-					name = pos + 1;
-				}
-				else
-				{
-					name = NULL;
-				}
-
-				/* the bookmarks file should contain valid
-				 * URIs, but paranoia is good */
-				location = g_file_new_for_uri (*line);
-				if (gedit_utils_is_valid_location (location))
-				{
-					added |= add_bookmark (model, name, *line);
-				}
-				g_object_unref (location);
-			}
-		}
-
-		g_strfreev (lines);
-		g_free (contents);
-
-		/* Add a watch */
-		if (model->priv->bookmarks_monitor == NULL)
-		{
-			GFile *file;
-
-			file = g_file_new_for_path (bookmarks);
-			model->priv->bookmarks_monitor = g_file_monitor_file (file, G_FILE_MONITOR_NONE, NULL, NULL);
-			g_object_unref (file);
-
-			g_signal_connect (model->priv->bookmarks_monitor,
-					  "changed",
-					  G_CALLBACK (on_bookmarks_file_changed),
-					  model);
-		}
-	}
-	else
-	{
-		/* The bookmarks file doesn't exist (which is perfectly fine) */
-		g_error_free (error);
+		/* try the old location (gtk <= 3.4) */
+		bookmarks = get_legacy_bookmarks_file ();
+		parse_bookmarks_file (model, bookmarks, &added);
 	}
 
 	if (added)
 	{
 		/* Bookmarks separator */
-		add_node (model, NULL, NULL, NULL,
-			  GEDIT_FILE_BOOKMARKS_STORE_IS_BOOKMARK |
-			  GEDIT_FILE_BOOKMARKS_STORE_IS_SEPARATOR, NULL);
+		add_node (model, NULL, NULL, NULL, NULL,
+			  GEDIT_FILE_BOOKMARKS_STORE_IS_BOOKMARK | GEDIT_FILE_BOOKMARKS_STORE_IS_SEPARATOR,
+			  NULL);
 	}
 
 	g_free (bookmarks);
@@ -663,12 +660,10 @@ bookmarks_compare_flags (GtkTreeModel *model,
 			 GtkTreeIter  *a,
 			 GtkTreeIter  *b)
 {
+	guint sep = GEDIT_FILE_BOOKMARKS_STORE_IS_SEPARATOR;
 	guint f1;
 	guint f2;
 	gint *flags;
-	guint sep;
-
-	sep = GEDIT_FILE_BOOKMARKS_STORE_IS_SEPARATOR;
 
 	gtk_tree_model_get (model, a,
 			    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_FLAGS, &f1,
@@ -704,9 +699,7 @@ bookmarks_compare_func (GtkTreeModel *model,
 			GtkTreeIter  *b,
 			gpointer      user_data)
 {
-	gint result;
-
-	result = bookmarks_compare_flags (model, a, b);
+	gint result = bookmarks_compare_flags (model, a, b);
 
 	if (result == 0)
 		result = bookmarks_compare_names (model, a, b);
@@ -731,11 +724,11 @@ find_with_flags (GtkTreeModel *model,
 
 	do
 	{
-		gtk_tree_model_get (model, &child,
-				    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_OBJECT,
-				    &childobj,
-				    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_FLAGS,
-				    &childflags, -1);
+		gtk_tree_model_get (model,
+				    &child,
+				    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_OBJECT, &childobj,
+				    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_FLAGS, &childflags,
+				    -1);
 
 		fequal = (obj == childobj);
 
@@ -756,11 +749,13 @@ find_with_flags (GtkTreeModel *model,
 }
 
 static void
-remove_node (GtkTreeModel *model, GtkTreeIter *iter)
+remove_node (GtkTreeModel *model,
+	     GtkTreeIter  *iter)
 {
 	guint flags;
 
-	gtk_tree_model_get (model, iter,
+	gtk_tree_model_get (model,
+			    iter,
 			    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_FLAGS, &flags,
 			    -1);
 
@@ -804,6 +799,7 @@ gedit_file_bookmarks_store_new (void)
 	GType column_types[] = {
 		GDK_TYPE_PIXBUF,
 		G_TYPE_STRING,
+		G_TYPE_STRING,
 		G_TYPE_OBJECT,
 		G_TYPE_UINT
 	};
@@ -838,11 +834,10 @@ gedit_file_bookmarks_store_get_location (GeditFileBookmarksStore *model,
 	g_return_val_if_fail (GEDIT_IS_FILE_BOOKMARKS_STORE (model), NULL);
 	g_return_val_if_fail (iter != NULL, NULL);
 
-	gtk_tree_model_get (GTK_TREE_MODEL (model), iter,
-			    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_FLAGS,
-			    &flags,
-			    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_OBJECT,
-			    &obj,
+	gtk_tree_model_get (GTK_TREE_MODEL (model),
+			    iter,
+			    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_FLAGS, &flags,
+			    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_OBJECT, &obj,
 			    -1);
 
 	if (obj == NULL)
@@ -853,7 +848,7 @@ gedit_file_bookmarks_store_get_location (GeditFileBookmarksStore *model,
 	if (isfs && (flags & GEDIT_FILE_BOOKMARKS_STORE_IS_MOUNT))
 		file = g_mount_get_root (G_MOUNT (obj));
 	else if (!isfs)
-		file = g_object_ref (obj);
+		file = (GFile *)g_object_ref (obj);
 
 	g_object_unref (obj);
 
@@ -924,4 +919,4 @@ _gedit_file_bookmarks_store_register_type (GTypeModule *type_module)
 	gedit_file_bookmarks_store_register_type (type_module);
 }
 
-/* ex:ts=8:noet: */
+/* ex:set ts=8 noet: */
